# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [1.2.2] - 2026 04 01
### Changed
- initialization

## [1.1.0] - 2026 03 26
### Added
- Saves The Log Config To Disk
- runAltUnittest.sh
### Changed
- license and readme files

## [1.0.0] - 2026 03 06
### Added
- Initial Release Renamed and Ported Over From Personal Project
